abacusai.prediction_input — AbacusAI documentation

# `abacusai.prediction_input`

## Module Contents

### Classes

`PredictionInput` | Batch inputs

class abacusai.prediction_input.PredictionInput(client, featureGroupDatasetIds=None, datasetIdRemap=None, featureGroups={}, datasets={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Batch inputs

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupDatasetIds (list) – The list of dataset IDs to use as input

    - datasetIdRemap (dict) – Replacement datasets to swap as prediction input

    - featureGroups (PredictionFeatureGroup) – List of prediction feature groups

    - datasets (PredictionDataset) – List of prediction datasets

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict